@@ -367,6 +367,15 @@ renderFontWeight s = renderTextAttr Font_weight_ fw
   fontWeightAttr :: FontWeight -> AttributeValue
   fontWeightAttr FontWeightNormal = "normal"
   fontWeightAttr FontWeightBold   = "bold"
+  fontWeightAttr FontWeightLighter = "lighter"
+  fontWeightAttr FontWeightBolder  = "bolder"
+  fontWeightAttr FontWeightThin = "100"
+  fontWeightAttr FontWeightUltraLight = "200"
+  fontWeightAttr FontWeightLight = "300"
+  fontWeightAttr FontWeightMedium = "400"
+  fontWeightAttr FontWeightSemiBold = "600"
+  fontWeightAttr FontWeightUltraBold = "800"
+  fontWeightAttr FontWeightHeavy = "900"
 
 
 renderFontFamily :: Style v n -> [Attribute]
